@@ -18,7 +18,12 @@
 
 set -xe
 
-pyversion=${1:-"3.8.5"}
+if [ -z "$1" ];then
+  echo "Please supply python version as argument to build image." >> /dev/stderr
+  exit 2
+fi
+
+pyversion=$1
 
 pushd images/build-stage/${pyversion} && docker build -t fnproject/python:${pyversion}-dev . && popd
 pushd images/runtime/${pyversion} && docker build -t fnproject/python:${pyversion} . && popd
